@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -21,16 +22,15 @@ sys.path.insert(0, os.path.abspath('../..'))
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx.ext.intersphinx',
+    'sphinxcontrib.autohttp.flask',
     'sphinxcontrib.pecanwsme.rest',
-    'sphinxcontrib.httpdomain',
+    'oslosphinx',
     'wsmeext.sphinxext',
-    'openstackdocstheme',
 ]
 
 wsme_protocols = ['restjson', 'restxml']
 
-suppress_warnings = ['app.add_directive']
-
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
 # execute "export SPHINX_DEBUG=1" in your terminal to disable
@@ -43,7 +43,7 @@ master_doc = 'index'
 
 # General information about the project.
 project = u'solum'
-copyright = u'2014, Solum Contributors'
+copyright = u'2013, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -61,17 +61,8 @@ pygments_style = 'sphinx'
 # Sphinx are currently 'default' and 'sphinxdoc'.
 # html_theme_path = ["."]
 # html_theme = '_theme'
-html_theme = 'openstackdocs'
 html_static_path = ['_static']
 
-# openstackdocstheme options
-repository_name = 'openstack/solum'
-bug_project = 'solum'
-bug_tag = ''
-
-# Must set this variable to include year, month, day, hours, and minutes.
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
-
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
@@ -88,26 +79,5 @@ man_pages = [
 # If true, show URL addresses after external links.
 man_show_urls = True
 
-# -- Options for LaTeX output -------------------------------------------------
-
-# Grouping the document tree into LaTeX files. List of tuples
-# (source start file, target name, title, author, documentclass
-# [howto/manual]).
-latex_documents = [
-    ('index', 'doc-solum.tex', u'Solum Documentation',
-     u'OpenStack Foundation', 'manual'),
-]
-latex_domain_indices = False
-
-latex_elements = {
-    'makeindex': '',
-    'printindex': '',
-    'preamble': r'\setcounter{tocdepth}{3}',
-    'maxlistdepth': '10',
-}
-
-# Disable usage of xindy https://bugzilla.redhat.com/show_bug.cgi?id=1643664
-latex_use_xindy = False
-
-# Disable smartquotes, they don't work in latex
-smartquotes_excludes = {'builders': ['latex']}
+# Example configuration for intersphinx: refer to the Python standard library.
+intersphinx_mapping = {'http://docs.python.org/': None}
