@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # Copyright 2013 - Noorul Islam K M
 #
@@ -15,8 +16,6 @@
 
 import json
 
-from tempest.lib import exceptions as tempest_exceptions
-
 from functionaltests.api import base
 
 sample_data = {"name": "test_service",
@@ -76,10 +75,6 @@ class TestServiceController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_service(json_data['uuid'])
 
-    def test_services_create_none(self):
-        self.assertRaises(tempest_exceptions.BadRequest,
-                          self.client.post, 'v1/services', "{}")
-
     def test_services_get(self):
         uuid = self._create_service()
         resp, body = self.client.get('v1/services/%s' % uuid)
@@ -88,14 +83,11 @@ class TestServiceController(base.TestCase):
         self._assert_output_expected(json_data, sample_data)
         self._delete_service(uuid)
 
-    def test_services_get_not_found(self):
-        self.assertRaises(tempest_exceptions.NotFound,
-                          self.client.get, 'v1/services/not_found')
-
     def test_services_put(self):
         uuid = self._create_service()
-        updated_data = {"name": "test_service_updated",
+        updated_data = {"name": "test_service updated",
                         "description": "A test to create service updated",
+                        "project_id": "project_id updated",
                         "user_id": "user_id updated",
                         "service_type": "mysql updated",
                         "read_only": False}
@@ -106,27 +98,8 @@ class TestServiceController(base.TestCase):
         self._assert_output_expected(json_data, updated_data)
         self._delete_service(uuid)
 
-    def test_services_put_not_found(self):
-        updated_data = {"name": "test_service_updated",
-                        "description": "A test to create service updated",
-                        "user_id": "user_id updated",
-                        "service_type": "mysql updated",
-                        "read_only": False}
-        updated_json = json.dumps(updated_data)
-        self.assertRaises(tempest_exceptions.NotFound,
-                          self.client.put, 'v1/services/not_found',
-                          updated_json)
-
-    def test_services_put_none(self):
-        self.assertRaises(tempest_exceptions.BadRequest,
-                          self.client.put, 'v1/services/any', "{}")
-
     def test_services_delete(self):
         uuid = self._create_service()
         resp, body = self.client.delete('v1/services/%s' % uuid)
         self.assertEqual(resp.status, 204)
         self.assertEqual(body, '')
-
-    def test_services_delete_not_found(self):
-        self.assertRaises(tempest_exceptions.NotFound,
-                          self.client.delete, 'v1/services/not_found')
