@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # Copyright 2013 - Noorul Islam K M
 #
@@ -13,25 +14,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-import oslo_middleware.cors as cors_middleware
+from oslo.config import cfg
 import pecan
 
 from solum.api import auth
 from solum.api import config as api_config
 
-
 # Register options for the service
 API_SERVICE_OPTS = [
     cfg.IntOpt('port',
                default=9777,
                help='The port for the solum API server'),
-    cfg.HostAddressOpt('host',
-                       default='127.0.0.1',
-                       help='The listen IP for the solum API server'),
-    cfg.IntOpt('max_apps_per_tenant',
-               default=10,
-               help='Maximum number of application allowed per tenant'),
+    cfg.StrOpt('host',
+               default='127.0.0.1',
+               help='The listen IP for the solum API server')
 ]
 
 API_PLAN_OPTS = [
@@ -44,13 +40,6 @@ API_PLAN_OPTS = [
 CONF = cfg.CONF
 opt_group = cfg.OptGroup(name='api',
                          title='Options for the solum-api service')
-
-
-def list_opts():
-    yield 'api', API_SERVICE_OPTS
-    yield None, API_PLAN_OPTS
-
-
 CONF.register_group(opt_group)
 CONF.register_opts(API_SERVICE_OPTS, opt_group)
 CONF.register_opts(API_PLAN_OPTS)
@@ -63,7 +52,6 @@ def get_pecan_config():
 
 
 def setup_app(config=None):
-
     if not config:
         config = get_pecan_config()
 
@@ -74,11 +62,4 @@ def setup_app(config=None):
         logging=getattr(config, 'logging', {}),
         **app_conf
     )
-
-    app = auth.install(app, CONF)
-
-    # Create a CORS wrapper, and attach solum-specific defaults that must be
-    # supported on all CORS responses.
-    app = cors_middleware.CORS(app, CONF)
-
-    return app
+    return auth.install(app, CONF)
