@@ -18,7 +18,6 @@ import wsmeext.pecan as wsme_pecan
 from solum.api.controllers.v1.datamodel import sensor
 from solum.api.handlers import sensor_handler
 from solum.common import exception
-from solum.common import policy
 from solum import objects
 
 
@@ -29,34 +28,31 @@ class SensorController(rest.RestController):
         super(SensorController, self).__init__()
         self._id = sensor_id
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(sensor.Sensor, wtypes.text)
     def get(self):
         """Return this sensor."""
-        policy.check('show_sensor',
-                     pecan.request.security_context)
-        handler = sensor_handler.SensorHandler(pecan.request.security_context)
+        handler = sensor_handler.SensorHandler(
+            pecan.request.security_context)
         return sensor.Sensor.from_db_model(handler.get(self._id),
                                            pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(sensor.Sensor, wtypes.text, body=sensor.Sensor)
     def put(self, data):
         """Modify this sensor."""
-        policy.check('update_sensor',
-                     pecan.request.security_context)
-        handler = sensor_handler.SensorHandler(pecan.request.security_context)
+        handler = sensor_handler.SensorHandler(
+            pecan.request.security_context)
         obj = handler.update(self._id,
                              data.as_dict(objects.registry.Sensor))
         return sensor.Sensor.from_db_model(obj, pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
     def delete(self):
         """Delete this sensor."""
-        policy.check('delete_sensor',
-                     pecan.request.security_context)
-        handler = sensor_handler.SensorHandler(pecan.request.security_context)
+        handler = sensor_handler.SensorHandler(
+            pecan.request.security_context)
         handler.delete(self._id)
 
 
@@ -69,23 +65,21 @@ class SensorsController(rest.RestController):
             remainder = remainder[:-1]
         return SensorController(sensor_id), remainder
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(sensor.Sensor, wtypes.text,
                          body=sensor.Sensor, status_code=201)
     def post(self, data):
         """Create a new sensor."""
-        policy.check('create_sensor',
-                     pecan.request.security_context)
-        handler = sensor_handler.SensorHandler(pecan.request.security_context)
+        handler = sensor_handler.SensorHandler(
+            pecan.request.security_context)
         obj = handler.create(data.as_dict(objects.registry.Sensor))
         return sensor.Sensor.from_db_model(obj, pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose([sensor.Sensor])
     def get_all(self):
         """Return all sensors, based on the query provided."""
-        policy.check('get_sensors',
-                     pecan.request.security_context)
-        handler = sensor_handler.SensorHandler(pecan.request.security_context)
+        handler = sensor_handler.SensorHandler(
+            pecan.request.security_context)
         return [sensor.Sensor.from_db_model(obj, pecan.request.host_url)
                 for obj in handler.get_all()]
