@@ -17,7 +17,6 @@ import wsmeext.pecan as wsme_pecan
 from solum.api.controllers.v1.datamodel import service
 from solum.api.handlers import service_handler
 from solum.common import exception
-from solum.common import policy
 from solum import objects
 
 
@@ -28,35 +27,29 @@ class ServiceController(rest.RestController):
         super(ServiceController, self).__init__()
         self._id = service_id
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(service.Service)
     def get(self):
         """Return this service."""
-        policy.check('show_service',
-                     pecan.request.security_context)
         handler = service_handler.ServiceHandler(
             pecan.request.security_context)
         return service.Service.from_db_model(handler.get(self._id),
                                              pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(service.Service, body=service.Service)
     def put(self, data):
         """Modify this service."""
-        policy.check('update_service',
-                     pecan.request.security_context)
         handler = service_handler.ServiceHandler(
             pecan.request.security_context)
         res = handler.update(self._id,
                              data.as_dict(objects.registry.Service))
         return service.Service.from_db_model(res, pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(status_code=204)
     def delete(self):
         """Delete this service."""
-        policy.check('delete_service',
-                     pecan.request.security_context)
         handler = service_handler.ServiceHandler(
             pecan.request.security_context)
         return handler.delete(self._id)
@@ -71,25 +64,21 @@ class ServicesController(rest.RestController):
             remainder = remainder[:-1]
         return ServiceController(service_id), remainder
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose(service.Service, body=service.Service,
                          status_code=201)
     def post(self, data):
         """Create a new service."""
-        policy.check('create_service',
-                     pecan.request.security_context)
         handler = service_handler.ServiceHandler(
             pecan.request.security_context)
         return service.Service.from_db_model(
             handler.create(data.as_dict(objects.registry.Service)),
             pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_controller_exception
     @wsme_pecan.wsexpose([service.Service])
     def get_all(self):
         """Return all services, based on the query provided."""
-        policy.check('get_services',
-                     pecan.request.security_context)
         handler = service_handler.ServiceHandler(
             pecan.request.security_context)
         return [service.Service.from_db_model(ser, pecan.request.host_url)
