@@ -25,9 +25,10 @@ class OperationHandler(handler.Handler):
 
     def update(self, uuid, data):
         """Modify the operation."""
-        updated = objects.registry.Operation.update_and_save(self.context,
-                                                             uuid, data)
-        return updated
+        db_obj = objects.registry.Operation.get_by_uuid(self.context, uuid)
+        db_obj.update(data)
+        db_obj.save(self.context)
+        return db_obj
 
     def delete(self, uuid):
         """Delete the operation."""
