@@ -14,34 +14,34 @@
 
 """Starter script for the Solum API service."""
 
+import logging as std_logging
 import os
 import sys
+from wsgiref import simple_server
 
-import eventlet
-from eventlet import wsgi
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 
 from solum.api import app as api_app
 from solum.common import service
 from solum.openstack.common.gettextutils import _
+from solum.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
 
 
 def main():
-    eventlet.monkey_patch(socket=True, select=True, time=True)
     service.prepare_service(sys.argv)
 
     app = api_app.setup_app()
 
     # Create the WSGI server and start it
     host, port = cfg.CONF.api.host, cfg.CONF.api.port
+    srv = simple_server.make_server(host, port, app)
 
     LOG.info(_('Starting server in PID %s') % os.getpid())
-    LOG.debug("Configuration:")
-    logging.setup(cfg.CONF, 'solum')
+    LOG.debug(_("Configuration:"))
+    cfg.CONF.log_opt_values(LOG, std_logging.DEBUG)
 
     if host == '0.0.0.0':
         LOG.info(_('serving on 0.0.0.0:%(port)s, '
@@ -51,4 +51,4 @@ def main():
         LOG.info(_('serving on http://%(host)s:%(port)s') %
                  dict(host=host, port=port))
 
-    wsgi.server(eventlet.listen((host, port)), app)
+    srv.serve_forever()
