@@ -13,33 +13,18 @@
 # limitations under the License.
 
 import inspect
+import json
 
-from oslo_config import cfg
-from oslo_context import context
-
-AUTH_OPTS = [
-    cfg.StrOpt('solum_admin_tenant_id',
-               default='',
-               help='Tenant id of global admin'),
-]
-
-
-def list_opts():
-    yield None, AUTH_OPTS
-
-
-CONF = cfg.CONF
-CONF.register_opts(AUTH_OPTS)
+from solum.openstack.common import context
 
 
 class RequestContext(context.RequestContext):
     def __init__(self, auth_token=None, user=None, tenant=None, domain=None,
                  user_domain=None, project_domain=None, is_admin=False,
                  read_only=False, request_id=None, user_name=None, roles=None,
-                 auth_url=None, trust_id=None, auth_token_info=None):
+                 service_catalog=None):
         super(RequestContext, self).__init__(auth_token=auth_token,
-                                             user=user,
-                                             tenant=tenant,
+                                             user=user, tenant=tenant,
                                              domain=domain,
                                              user_domain=user_domain,
                                              project_domain=project_domain,
@@ -47,24 +32,32 @@ class RequestContext(context.RequestContext):
                                              read_only=read_only,
                                              show_deleted=False,
                                              request_id=request_id)
-        self.roles = roles or []
+        self.roles = roles
         self.user_name = user_name
-        self.auth_url = auth_url
-        self.trust_id = trust_id
-        self.auth_token_info = auth_token_info
-        global_admin_id = CONF.get('solum_admin_tenant_id')
-        if global_admin_id and global_admin_id == tenant:
-            self.is_admin = True
+        self._service_catalog_js = None
+        self.service_catalog = service_catalog
+
+    def get_url_for(self, service_type=None, endpoint_type=None):
+        if self._service_catalog_js is None:
+            self._service_catalog_js = json.loads(self.service_catalog)
+
+        for sc in self._service_catalog_js:
+            if sc['type'] == service_type:
+                for ep in sc['endpoints']:
+                    if endpoint_type in ep:
+                        return ep[endpoint_type]
+
+    @property
+    def auth_url(self):
+        return self.get_url_for(service_type='identity',
+                                endpoint_type='publicURL')
 
     def to_dict(self):
-        values = super(RequestContext, self).to_dict()
-        values.update({
-            'roles': self.roles,
-            'user_name': self.user_name,
-            'auth_url': self.auth_url,
-            'auth_token_info': self.auth_token_info,
-            'trust_id': self.trust_id})
-        return values
+        data = super(RequestContext, self).to_dict()
+        data.update(roles=self.roles,
+                    user_name=self.user_name,
+                    service_catalog=self.service_catalog)
+        return data
 
     @classmethod
     def from_dict(cls, values):
