@@ -10,12 +10,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_log import log as logging
+
 import requests
 from requests import exceptions
-from six import moves
 
-from solum.i18n import _
+from solum.openstack.common.gettextutils import _
+from solum.openstack.common import log as logging
+from solum.openstack.common.py3kcompat import urlutils
 
 LOG = logging.getLogger(__name__)
 
@@ -29,14 +30,12 @@ def get(url, max_size, chunk_size=None, allowed_schemes=('http', 'https')):
     The max_size represents the total max byte of your file.
     The chunk_size is by default set at max_size, it represents the size
     of your chunk.
-    Raise an IOError if getting the data fails.
-    Raise an IOError if max_size is less than 1.
-    Raise an IOError if chunk_size is less than 1.
+    Raise an IOError if getting the data fails and if max_size is exceeded.
     """
 
     LOG.info(_('Fetching data from %s') % url)
 
-    components = moves.urllib.parse.urlparse(url)
+    components = urlutils.urlparse(url)
 
     if components.scheme not in allowed_schemes:
         raise IOError(_('Invalid URL scheme %s') % components.scheme)
@@ -50,8 +49,8 @@ def get(url, max_size, chunk_size=None, allowed_schemes=('http', 'https')):
 
     if components.scheme == 'file':
         try:
-            return moves.urllib.request.urlopen(url).read()
-        except moves.urllib.error.URLError as uex:
+            return urlutils.urlopen(url).read()
+        except urlutils.URLError as uex:
             raise IOError(_('Failed to read file: %s') % str(uex))
 
     try:
