@@ -16,11 +16,14 @@
 
 from solum.deployer import api
 from solum import objects
+from solum.objects import image
 from solum.openstack.common.gettextutils import _
 from solum.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
+IMAGE_STATES = image.States
+
 
 class Handler(object):
     def __init__(self):
@@ -48,6 +51,6 @@ class Handler(object):
                                                              'Image Build',
                                                              'Image Build job',
                                                              created_image_id)
-            if image.status == 'COMPLETE':
+            if image.status == IMAGE_STATES.COMPLETE:
                 api.API(context=ctxt).deploy(assembly_id=assem.id,
                                              image_id=image.created_image_id)
