@@ -14,27 +14,16 @@
 
 """Solum Deployer noop handler."""
 
-from oslo_log import log as logging
-
-from solum import objects
+from solum.openstack.common.gettextutils import _
+from solum.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
 
 class Handler(object):
     def echo(self, ctxt, message):
-        LOG.debug("%s" % message)
+        LOG.debug(_("%s") % message)
 
-    def deploy(self, ctxt, assembly_id, image_id, ports):
-        message = ("Deploy %s %s %s" % (assembly_id, image_id, ports))
-        LOG.debug("%s" % message)
-
-    def destroy_assembly(self, ctxt, assem_id):
-        assem = objects.registry.Assembly.get_by_id(ctxt, assem_id)
-        assem.destroy(ctxt)
-        message = ("Destroy %s" % (assem_id))
-        LOG.debug("%s" % message)
-
-    def destroy_app(self, ctxt, app_id):
-        message = ("Destroy App %s" % (app_id))
-        LOG.debug("%s" % message)
+    def deploy(self, ctxt, assembly_id, image_id):
+        message = ("Deploy %s %s" % (assembly_id, image_id))
+        LOG.debug(_("%s") % message)
