@@ -13,16 +13,12 @@
 # under the License.
 
 import sqlalchemy as sa
-from sqlalchemy.orm import exc
 
+from solum.common import exception
 from solum import objects
 from solum.objects import assembly as abstract
 from solum.objects.sqlalchemy import component
 from solum.objects.sqlalchemy import models as sql
-from solum.objects.sqlalchemy import plan as plan_obj
-
-ASSEMBLY_STATES = abstract.States
-retry = sql.retry
 
 
 class Assembly(sql.Base, abstract.Assembly):
@@ -36,24 +32,26 @@ class Assembly(sql.Base, abstract.Assembly):
     uuid = sa.Column(sa.String(36), nullable=False)
     project_id = sa.Column(sa.String(36))
     user_id = sa.Column(sa.String(36))
+    trigger_id = sa.Column(sa.String(36))
     name = sa.Column(sa.String(100))
     description = sa.Column(sa.String(255))
     tags = sa.Column(sa.Text)
     plan_id = sa.Column(sa.Integer, sa.ForeignKey('plan.id'), nullable=False)
     status = sa.Column(sa.String(36))
     application_uri = sa.Column(sa.String(1024))
-    username = sa.Column(sa.String(256))
-    workflow = sa.Column(sql.YAMLEncodedDict(1024))
-    image_id = sa.Column(sa.Integer)
 
-    def _non_updatable_fields(self):
-        return set(('uuid', 'id', 'project_id'))
+    @classmethod
+    def _raise_trigger_not_found(cls, item_id):
+        """Raise a NotFound exception."""
+        raise exception.ResourceNotFound(id=item_id, name='trigger')
 
-    def _is_updatable(self):
-        if self.status == ASSEMBLY_STATES.DELETING:
-            return False
-        else:
-            return True
+    @classmethod
+    def get_by_trigger_id(cls, context, trigger_id):
+        try:
+            session = sql.Base.get_session()
+            return session.query(cls).filter_by(trigger_id=trigger_id).one()
+        except sa.orm.exc.NoResultFound:
+            cls._raise_trigger_not_found(trigger_id)
 
     @property
     def plan_uuid(self):
@@ -66,7 +64,7 @@ class Assembly(sql.Base, abstract.Assembly):
 
     @property
     def _extra_keys(self):
-        return ['plan_uuid', 'created_at', 'updated_at']
+        return ['plan_uuid']
 
     @property
     def components(self):
@@ -74,45 +72,10 @@ class Assembly(sql.Base, abstract.Assembly):
         return session.query(component.Component).filter_by(
             assembly_id=self.id).all()
 
-    @retry
-    def destroy(self, context):
-        session = sql.Base.get_session()
-        with session.begin():
-            session.query(component.Component).filter_by(
-                assembly_id=self.id).delete()
-            session.query(self.__class__).filter_by(
-                id=self.id).delete()
-
-    @property
-    def heat_stack_component(self):
-        session = sql.Base.get_session()
-        return session.query(component.Component).filter_by(
-            assembly_id=self.id, component_type='heat_stack').first()
-
 
 class AssemblyList(abstract.AssemblyList):
     """Represent a list of assemblies in sqlalchemy."""
 
     @classmethod
     def get_all(cls, context):
-        mq = sql.model_query(context, Assembly).order_by(
-            'updated_at desc', 'created_at desc')
-        return AssemblyList(mq)
-
-    @classmethod
-    def get_earlier(cls, assem_id, app_id, status, created_at):
-        try:
-            session = sql.Base.get_session()
-            result = session.query(plan_obj.Plan)
-            result = result.filter(plan_obj.Plan.id == app_id)
-            app_uuid = result.one().uuid
-            result = session.query(plan_obj.Plan)
-            result = result.filter(plan_obj.Plan.uuid == app_uuid).all()
-            plan_id_list = [plan.id for plan in result]
-
-            result = session.query(Assembly)
-            result = result.filter(Assembly.plan_id.in_(plan_id_list))
-            result = result.filter(Assembly.created_at < created_at)
-            return result.all()
-        except exc.NoResultFound:
-            cls._raise_not_found(assem_id)
+        return AssemblyList(sql.model_query(context, Assembly))
