@@ -79,7 +79,7 @@ def upgrade():
         sa.Column('base_image_id', sa.String(length=36)),
         sa.Column('created_image_id', sa.String(length=36)),
         sa.Column('image_format', sa.String(length=12)),
-        sa.Column('source_format', sa.String(length=36)),
+        sa.Column('source_format', sa.String(length=12)),
     )
 
     op.create_table(
@@ -105,10 +105,9 @@ def upgrade():
         sa.Column('updated_at', sa.DateTime, onupdate=timeutils.utcnow),
         sa.Column('project_id', sa.String(length=36)),
         sa.Column('user_id', sa.String(length=36)),
-        sa.Column('raw_content', models.YAMLEncodedDict(2048)),
+        sa.Column('raw_content', models.JSONEncodedDict(2048)),
         sa.Column('description', sa.String(length=255)),
         sa.Column('name', sa.String(255)),
-        sa.Column('deploy_keys_uri', sa.String(length=1024)),
     )
 
     op.create_table(
@@ -126,52 +125,9 @@ def upgrade():
                   nullable=False),
         sa.Column('status', sa.String(length=36)),
         sa.Column('trigger_id', sa.String(length=36)),
-        sa.Column('trust_id', sa.String(length=255)),
         sa.Column('application_uri', sa.String(length=1024)),
     )
 
-    op.create_table(
-        'pipeline',
-        sa.Column('id', sa.Integer, primary_key=True, nullable=False),
-        sa.Column('uuid', sa.String(length=36), nullable=False),
-        sa.Column('created_at', sa.DateTime, default=timeutils.utcnow),
-        sa.Column('updated_at', sa.DateTime, onupdate=timeutils.utcnow),
-        sa.Column('name', sa.String(100)),
-        sa.Column('description', sa.String(255)),
-        sa.Column('project_id', sa.String(36)),
-        sa.Column('user_id', sa.String(36)),
-        sa.Column('tags', sa.Text),
-        sa.Column('plan_id', sa.Integer, sa.ForeignKey('plan.id'),
-                  nullable=False),
-        sa.Column('workbook_name', sa.String(length=255)),
-        sa.Column('trigger_id', sa.String(length=36)),
-        sa.Column('trust_id', sa.String(length=255)),
-    )
-
-    op.create_table(
-        'execution',
-        sa.Column('id', sa.Integer, primary_key=True, nullable=False),
-        sa.Column('uuid', sa.String(length=36), nullable=False),
-        sa.Column('pipeline_id', sa.Integer, sa.ForeignKey('pipeline.id')),
-        sa.Column('created_at', sa.DateTime, default=timeutils.utcnow),
-        sa.Column('updated_at', sa.DateTime, onupdate=timeutils.utcnow),
-    )
-
-    op.create_table(
-        'infrastructure_stack',
-        sa.Column('id', sa.Integer, primary_key=True, nullable=False),
-        sa.Column('uuid', sa.String(length=36), nullable=False),
-        sa.Column('created_at', sa.DateTime, default=timeutils.utcnow),
-        sa.Column('updated_at', sa.DateTime, onupdate=timeutils.utcnow),
-        sa.Column('name', sa.String(100)),
-        sa.Column('description', sa.String(255)),
-        sa.Column('project_id', sa.String(36)),
-        sa.Column('user_id', sa.String(36)),
-        sa.Column('tags', sa.Text),
-        sa.Column('image_id', sa.String(36), nullable=False),
-        sa.Column('heat_stack_id', sa.String(36)),
-    )
-
     op.create_table(
         'component',
         sa.Column('id', sa.Integer, primary_key=True, nullable=False),
@@ -179,7 +135,6 @@ def upgrade():
         sa.Column('created_at', sa.DateTime, default=timeutils.utcnow),
         sa.Column('updated_at', sa.DateTime, onupdate=timeutils.utcnow),
         sa.Column('name', sa.String(100)),
-        sa.Column('component_type', sa.String(100)),
         sa.Column('description', sa.String(255)),
         sa.Column('project_id', sa.String(36)),
         sa.Column('user_id', sa.String(36)),
@@ -188,7 +143,6 @@ def upgrade():
         sa.Column('parent_component_id', sa.Integer,
                   sa.ForeignKey('component.id')),
         sa.Column('resource_uri', sa.String(length=1024)),
-        sa.Column('heat_stack_id', sa.String(36)),
     )
 
     op.create_table(
