@@ -23,10 +23,8 @@ __all__ = ['FunctionalTest']
 
 
 class FunctionalTest(base.BaseTestCase):
-    """Used for functional tests.
-
-    Where you need to test your literal application and its
-    integration with the framework.
+    """Used for functional tests where you need to test your
+    literal application and its integration with the framework.
     """
 
     def setUp(self):
@@ -43,4 +41,4 @@ class FunctionalTest(base.BaseTestCase):
     def assertResourceNotFound(self, url):
         resp = self.app.get(url, status=404,
                             headers={'Accept': 'application/json'})
-        self.assertEqual(404, resp.status_int)
+        self.assertEqual(resp.status_int, 404)
