@@ -43,10 +43,23 @@ class TestSensorHandler(base.BaseTestCase):
 
     def test_sensor_update(self, mock_registry):
         data = {'name': 'new_user_name'}
+        db_obj = fakes.FakeSensor()
+        mock_registry.Sensor.get_by_uuid.return_value = db_obj
         handler = sensor.SensorHandler(self.ctx)
-        handler.update('test_id', data)
-        mock_registry.Sensor.update_and_save.assert_called_once_with(
-            self.ctx, 'test_id', data)
+        res = handler.update('test_id', data)
+        self.assertEqual(db_obj.user_id, res.user_id)
+        self.assertEqual(db_obj.project_id, res.project_id)
+        self.assertEqual(db_obj.name, res.name)
+        self.assertEqual(db_obj.value, res.value)
+        self.assertEqual(db_obj.sensor_type, res.sensor_type)
+        self.assertEqual(db_obj.target_resource, res.target_resource)
+        self.assertEqual(db_obj.uuid, res.uuid)
+        self.assertEqual(db_obj.uri, res.uri)
+        self.assertEqual(db_obj.type, res.type)
+        db_obj.update.assert_called_once_with(data)
+        db_obj.save.assert_called_once_with(self.ctx)
+        mock_registry.Sensor.get_by_uuid.assert_called_once_with(self.ctx,
+                                                                 'test_id')
 
     def test_sensor_create(self, mock_registry):
         data = {'name': 'new_name',
@@ -57,7 +70,7 @@ class TestSensorHandler(base.BaseTestCase):
         res = handler.create(data)
         db_obj.update.assert_called_once_with(data)
         db_obj.create.assert_called_once_with(self.ctx)
-        self.assertEqual(db_obj, res)
+        self.assertEqual(res, db_obj)
 
     def test_sensor_delete(self, mock_registry):
         db_obj = fakes.FakeSensor()
