@@ -13,10 +13,10 @@
 # under the License.
 
 import mock
-from oslo_config import fixture as config
 
 from solum.api import auth
 from solum.common import context
+from solum.openstack.common.fixture import config
 from solum.tests import base
 from solum.tests import fakes
 
@@ -32,18 +32,18 @@ class TestAuth(base.BaseTestCase):
 
     def test_check_auth_option_enabled(self, mock_auth):
 
-        self.CONF.config(auth_protocol="http",
+        self.CONF.config(auth_protocol="footp",
                          auth_version="v2.0",
-                         www_authenticate_uri=None,
+                         auth_uri=None,
                          group=auth.OPT_GROUP_NAME)
         self.CONF.config(enable_authentication=True)
         result = auth.install(self.app, self.CONF.conf)
         self.assertIsInstance(result, fakes.FakeAuthProtocol)
 
     def test_check_auth_option_disabled(self, mock_auth):
-        self.CONF.config(auth_protocol="http",
+        self.CONF.config(auth_protocol="footp",
                          auth_version="v2.0",
-                         www_authenticate_uri=None,
+                         auth_uri=None,
                          group=auth.OPT_GROUP_NAME)
         self.CONF.config(enable_authentication=False)
         result = auth.install(self.app, self.CONF.conf)
@@ -63,8 +63,8 @@ class TestAuth(base.BaseTestCase):
                          fakes.fakeAuthTokenHeaders['X-User-Id'])
         self.assertEqual(ctx.roles,
                          [u'admin', u'ResellerAdmin', u'_member_'])
-        self.assertEqual(ctx.auth_url,
-                         fakes.fakeAuthTokenHeaders['X-Auth-Url'])
+        self.assertEqual(ctx.service_catalog,
+                         fakes.fakeAuthTokenHeaders['X-Service-Catalog'])
         self.assertEqual(ctx.user_name,
                          fakes.fakeAuthTokenHeaders['X-User-Name'])
         self.assertEqual(ctx.domain,
@@ -73,15 +73,3 @@ class TestAuth(base.BaseTestCase):
                          fakes.fakeAuthTokenHeaders['X-Project-Domain-Id'])
         self.assertEqual(ctx.user_domain,
                          fakes.fakeAuthTokenHeaders['X-User-Domain-Id'])
-        self.assertIsNone(ctx.auth_token_info)
-
-    def test_auth_hook_before_method_auth_info(self, mock_cls):
-        state = mock.Mock(request=fakes.FakePecanRequest())
-        state.request.environ['keystone.token_info'] = 'assert_this'
-        hook = auth.AuthInformationHook()
-        hook.before(state)
-        ctx = state.request.security_context
-        self.assertIsInstance(ctx, context.RequestContext)
-        self.assertEqual(fakes.fakeAuthTokenHeaders['X-Auth-Token'],
-                         ctx.auth_token)
-        self.assertEqual('assert_this', ctx.auth_token_info)
