@@ -10,19 +10,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from io import StringIO
+import mock
 from requests import exceptions
-from unittest import mock
-import urllib
+from six import moves
 
 from solum.common import urlfetch
+from solum.openstack.common.py3kcompat import urlutils
 from solum.tests import base
 
 
 FETCH_SIZE_OK = 500
 
 
-class Response(object):
+class Response:
     def __init__(self, buf=''):
         self.buf = buf
 
@@ -101,17 +101,17 @@ class TestUrlFetch(base.BaseTestCase):
         self.assertRaises(IOError, urlfetch.get, 'file:///etc/profile',
                           FETCH_SIZE_OK)
 
-    @mock.patch('urllib.request.urlopen')
+    @mock.patch('solum.common.urlfetch.urlutils.urlopen')
     def test_file_scheme_supported(self, mock_urlopen):
         data = '{ "foo": "bar" }'
         url = 'file:///etc/profile'
-        mock_urlopen.return_value = StringIO(data)
+        mock_urlopen.return_value = moves.cStringIO(data)
         self.assertEqual(data, urlfetch.get(url, FETCH_SIZE_OK,
                                             allowed_schemes=['file']))
 
-    @mock.patch('urllib.request.urlopen')
+    @mock.patch('solum.common.urlfetch.urlutils.urlopen')
     def test_file_scheme_failure(self, mock_urlopen):
         url = 'file:///etc/profile'
-        mock_urlopen.side_effect = urllib.error.URLError('oops')
+        mock_urlopen.side_effect = urlutils.URLError('oops')
         self.assertRaises(IOError, urlfetch.get, url, FETCH_SIZE_OK,
                           allowed_schemes=['file'])
