@@ -12,12 +12,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from unittest import mock
+import mock
 
-from solum.i18n import _
+from solum.openstack.common.gettextutils import _
 from solum.tests import base
 from solum.tests import utils
-from solum.tests.worker.handlers import test_shell
 from solum.worker.handlers import noop as noop_handler
 
 
@@ -33,18 +32,8 @@ class HandlerTest(base.BaseTestCase):
 
     @mock.patch('solum.worker.handlers.noop.LOG')
     def test_build(self, fake_LOG):
-        git_info = test_shell.mock_git_info()
-        args = [5, git_info, 'new_app', '1-2-3-4', 'heroku', 'docker',
-                44, None, None]
+        args = [5, 'git://example.com/foo', 'new_app',
+                '1-2-3-4', 'heroku', 'docker', 44]
         noop_handler.Handler().build(self.ctx, *args)
-        message = 'Build ' + ', '.join([str(a) for a in args])
-        fake_LOG.debug.assert_called_once_with(_("%s") % message)
-
-    @mock.patch('solum.worker.handlers.noop.LOG')
-    def test_unittest(self, fake_LOG):
-        git_info = test_shell.mock_git_info()
-        args = [5, git_info, 'new_app',
-                '1-2-3-4', 'heroku', 'docker', 44, 'pep8']
-        noop_handler.Handler().unittest(self.ctx, *args)
-        message = 'Unittest ' + ', '.join([str(a) for a in args])
+        message = 'Build %s %s %s %s %s %s %s' % tuple(args)
         fake_LOG.debug.assert_called_once_with(_("%s") % message)
